@@ -26,14 +26,17 @@ class Config:
         return {
             "stylesheets": [],
             "scripts": [
-                "https://code.highcharts.com/8/highcharts.js",
-                "https://code.highcharts.com/8/highcharts-more.js",
-                "https://code.highcharts.com/8/modules/heatmap.js",
-                "https://code.highcharts.com/8/modules/exporting.js",
-                "https://code.highcharts.com/8/modules/offline-exporting.js",
-                "https://code.highcharts.com/8/modules/export-data.js",
+                "https://code.highcharts.com/highcharts.js",
+                "https://code.highcharts.com/highcharts-more.js",
+                "https://code.highcharts.com/modules/heatmap.js",
+                "https://code.highcharts.com/modules/exporting.js",
+                "https://code.highcharts.com/modules/offline-exporting.js",
+                "https://code.highcharts.com/modules/export-data.js",
+                "https://code.highcharts.com/modules/annotations.js",
+                "https://code.highcharts.com/modules/accessibility.js",
             ],
             "theme": "easychart",
+            "rendering": {"container": {"width": 985}, "responsive": False,},
         }
 
     def load(self):
@@ -41,7 +44,7 @@ class Config:
         Load the configuration
         """
         # load the default values
-        config = self.defaults
+        config = {**self.defaults}
 
         # load the user configuration
         if os.path.exists(self.filename):
@@ -72,6 +75,7 @@ class Config:
         Resets and overrides the user configuration
         """
         self.config = easytree.Tree(self.defaults)
+
         if save:
             self.save()
         return
